#Bhavesh Sareen

#Topsis Package

##INSTALLATION GUIDE

#pip install Topsis-Bhavesh-101917080

##USAGE GUIDE

#import topsis
#topsis.topsis("input_file.csv", "1,1,1,1", "+,-,+,-") 


#Bhavesh Sareen 2022